@@ -38,6 +38,7 @@ type Error = Box<dyn std::error::Error>;
 const SHOW_PREVIEW_COMMAND: &str = "showPreview";
 
 #[derive(Clone, clap::Parser)]
+#[clap(author, version, about, long_about = None)]
 struct Cli {
     #[clap(
         short = 'I',
@@ -47,7 +48,7 @@ struct Cli {
     )]
     include_paths: Vec<std::path::PathBuf>,
 
-    /// The style name for the preview ('native', 'fluent' or 'ugly')
+    /// The style name for the preview ('native' or 'fluent')
     #[clap(long, name = "style name", default_value_t)]
     style: String,
 
@@ -310,12 +311,16 @@ fn handle_request(
 fn cast<Kind: lsp_types::request::Request>(
     req: &mut Option<Request>,
 ) -> Option<(RequestId, Kind::Params)> {
-    match req.take().unwrap().extract::<Kind::Params>(Kind::METHOD) {
+    match req.take()?.extract::<Kind::Params>(Kind::METHOD) {
         Ok(value) => Some(value),
-        Err(owned) => {
+        Err(lsp_server::ExtractError::MethodMismatch(owned)) => {
             *req = Some(owned);
             None
         }
+        Err(e) => {
+            eprintln!("Warning: error when deserializing request: {}", e);
+            None
+        }
     }
 }
 
